Stan Math Library: stan/math/fwd/scal/fun/cosh.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

cosh.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_COSH_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_COSH_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
10 template <typename T>
11 inline
12 fvar<T>
13 cosh(const fvar<T>& x) {
14 using std::sinh;
15 using std::cosh;
16 return fvar<T>(cosh(x.val_), x.d_ * sinh(x.val_));
17 }
18
19 }
20 }
21 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::cosh
fvar< T > cosh(const fvar< T > &x)
Definition: cosh.hpp:13
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::cosh
var cosh(const var &a)
Return the hyperbolic cosine of the specified variable (cmath).
Definition: cosh.hpp:50
stan::math::sinh
fvar< T > sinh(const fvar< T > &x)
Definition: sinh.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.